# Changelog

<!--next-version-placeholder-->

## v1.6.0 (2022-11-30)
### Feature
* Add support for annotation-only attributes ([`fb8a4d4`](https://github.com/kalekundert/autoclasstoc/commit/fb8a4d4d1ab83a52ee6276d511fba6fcea7863ac))

### Fix
* Accomodate parent classes that can't be imported ([`2f8b2c1`](https://github.com/kalekundert/autoclasstoc/commit/2f8b2c10315eedd712cdac75953ee49cb17e9808))
* Correctly reference inherited attributes ([`f0c61ab`](https://github.com/kalekundert/autoclasstoc/commit/f0c61ab8b9e4ae31c22afc8706dbf75ddd612567))
* Correctly handle some niche error cases ([`02d63cf`](https://github.com/kalekundert/autoclasstoc/commit/02d63cf63de549a2318624fc9a8a8ed4bab22ffa))
* Correctly add the 'open' attribute to <details> elements ([`3adaa6e`](https://github.com/kalekundert/autoclasstoc/commit/3adaa6e74ec3ee0a390a3459d639465884b476a0))

## v1.5.2 (2022-10-10)
### Fix
* Link to (rather than copy) parent class members ([`b1eebd0`](https://github.com/kalekundert/autoclasstoc/commit/b1eebd0a41ce73f012f835ef53a41da33ade3d19))

### Documentation
* Use unicode homoglyphs to fix documentation error ([`d948ea7`](https://github.com/kalekundert/autoclasstoc/commit/d948ea79c431e2bdd689a976f2fa618fea1043d2))

## v1.5.1 (2022-04-08)
### Fix
* Remove extra spaces from :py:class: ([`fc547f6`](https://github.com/kalekundert/autoclasstoc/commit/fc547f654391ae798a54d9ed136ada3676920660))

## v1.5.0 (2022-03-10)
### Feature
* Allow sections to exclude other sections ([`b757374`](https://github.com/kalekundert/autoclasstoc/commit/b75737451abcfd16a1cda2f3a02d8ba8a2ed43cd))
* Be more precise about what's considered public ([`fbda744`](https://github.com/kalekundert/autoclasstoc/commit/fbda7444c54e1e51c3699f13caada2d8c374a98b))

## v1.4.0 (2022-03-10)
### Feature
* Add `exclude_pattern` to `Section` class ([#18](https://github.com/kalekundert/autoclasstoc/issues/18)) ([`4b796ac`](https://github.com/kalekundert/autoclasstoc/commit/4b796ac5a25bd785e64da4e2f24fdee23f1278ea))

## v1.3.0 (2021-09-14)
### Feature
* Support sphinx~=4.0 ([`405954d`](https://github.com/kalekundert/autoclasstoc/commit/405954d39db5fdb7e3c491a81cce39a82f963231))

### Documentation
* Fix warnings ([`a7d5ade`](https://github.com/kalekundert/autoclasstoc/commit/a7d5ade64c54ef9b3d06e19761874d30407bf331))

## v1.2.1 (2021-09-07)
### Fix
* **utils:** Add missing "f" in "f"string ([`446fa95`](https://github.com/kalekundert/autoclasstoc/commit/446fa95611317922cbc5e1270ef5fc06b79ebeb6))

### Documentation
* Add glooey as an example project ([`34f521f`](https://github.com/kalekundert/autoclasstoc/commit/34f521f4c776d929a43566567f9a09b543c19755))
